
**************************************************************************	
*****  MERGING THE HRS AND SHARE DATA FOR THE ANALYSIS ORIGINAL DATA *****
**************************************************************************


global workingDir 	"C:\Users\liliy\Dropbox\01_Projects\03_SHARE_CAD_edu_health\04_dofiles\Leopold_2018"

global working 		"${workingDir}/01_working_data"	   // working data - data saved after merging and recodings
global tables 		"${workingDir}/02_tables" 		   // tables 
global graphs 		"${workingDir}/03_graphs" 		   // graphs
global graphspap 	"${workingDir}/03_graphs/Paper"    // graphs
global dofiles 		"${workingDir}/04_dofiles" 		   // do-files	



use $working\180918_an.dta, replace


************ TABLE 2 ******************************************

label var age_years "Age"
label var yrbirth "Year of birth"
label var age_w1 "Cohort"

label var chron_hrs4 "Nr. of chronic conditions"
label var high_BP "High blood pressure"
label var diabet  "Diabetes"
label var stroke  "Stroke"
label var lung_di "Lung disease"


label var died "Died"
label var dropout "Dropout"

bys mergeid (svyear) : gen nr_waves = _N

** timevarying
foreach nr in 1 2 3 4 {
			 estpost su  ///
			 age_years   ///
			 chron_hrs4 high_BP diabet stroke lung_di mobility ///
			 walk sit chair stair stair1 stoop arms push lift dime ///
			 svyear ///
			 ///
			 if country_4 ==`nr',detail
	  est store country`nr', title("`X'") 
	}
		 esttab  country1 country2 country3 country4 ///
		 using "${workingDir}/02_tables/table2_tv.rtf", ///
		 rtf cells("mean(fmt(a2)) sd min max") replace/*
		*/ compress  mtitles title("Sample Statistics") ///
		stats(ind N, fmt(0 0)) label 

** time constant		
foreach nr in 1 2 3 4 {
			 estpost su  ///
			  yrbirth age_w1  ///
			 edu_1 edu_2 edu_3 ///
			 male ///
			 died dropout nr_waves black ///
			 if country_4 ==`nr' & n==1,detail
	  est store country`nr', title("`X'") 
	}
		 esttab  country1 country2 country3 country4 ///
		 using "${workingDir}/02_tables/table2_tc.rtf", ///
		 rtf cells("mean(fmt(a2)) sd min max") replace/*
		*/ compress  mtitles title("Sample Statistics") ///
		stats(ind N, fmt(0 0)) label 

************* Figure 1 ******************************************

recode age_w1 (50/54 = 3) (55/60 = 2) (61/65 =1), gen (coh_gr)
label de coh 3 "1950-54" 2 "1944-49" 1 "1939-43"
labe val coh_gr coh

label de cohuk 3 "1948-52" 2 "1942-47" 1 "1937-41"
labe val coh_gr cohuk

graph bar edu_1 edu_2 edu_3 if n==1, percent over(coh_gr, gap(10)) over(country_4,gap(50))								       ///
graphregion(color(white) fcolor(white) icolor(white)) ///
bar(1, bcolor(gs14)) bar(2, bcolor(gs12)) bar(3, bcolor(gs10))	///
bar(4, bcolor(gs14)) bar(5, bcolor(gs12)) bar(6, bcolor(gs10)) ///
stack title("") ///
legend(title(Level of Education by Cohort, size(small)) 	///
label(1 "Lower" ) label(2 "Intermediate") label(3 "Higher") size(small) rows(1)) 													///
ytitle("%") ylabel(0 (10) 100,labsize(small) angle(0)) name(fig1, replace)
graph save $graphs/Figure_1.gph, replace

/* for legend for UK
graph bar edu_1 edu_2 edu_3 if n==1, percent over(coh_gr, gap(10)) over(country_4,gap(50))								       ///
graphregion(color(white) fcolor(white) icolor(white)) ///
bar(1, bcolor(gs14)) bar(2, bcolor(gs12)) bar(3, bcolor(gs10))	///
bar(4, bcolor(gs14)) bar(5, bcolor(gs12)) bar(6, bcolor(gs10)) ///
stack title("") ///
legend(title(Level of Education by Cohort, size(small)) 	///
label(1 "Lower" ) label(2 "Intermediate") label(3 "Higher") size(small) rows(1)) 													///
ytitle("%") ylabel(0 (10) 100,labsize(small) angle(0)) name(fig1, replace)
graph save $graphs/Figure_1_uk.gph, replace
*/ 


*****************************************************************************************
************* MULTIVARIATE ANALYSIS  ****************************************************
*****************************************************************************************

xtset num svyear

**** TABLE A1

eststo clear
foreach var of varlist chron_hrs4 mobility {
eststo `var': xtpoisson `var' ///   ESTIMATING THE MODEL
					c.age2_cent##i.country_4 c.age_cent##c.coh_cent##i.edu##i.country_4 [pweight = samp_weight]  ///
					,pa vce(robust) 	
esttab using "${workingDir}/02_tables/Table_A1.rtf", replace label b(a2) wide se(2) pr2	
}


*** TABLE 3 *********************************

* Here I estimate initial health differences between lower and higher educated for six cohorts 
* and differences 10 years later. I have further calculated (manually) the difference between these two 
* estimates as an indicator of change. 


** Chronic conditions

** Swewden
eststo clear
xtpoisson chron_hrs4 ///   
					c.age_years##c.age_years c.age_years##ib3.edu##c.age_w1 ///
					[pweight = samp_weight] ///
					if country_4 ==1, pa vce(robust) corr(uns)	
margins, dydx(edu) at(c.age_years = (50 60)       c.age_w1 = (50) )  vsquish post
est store e_1

xtpoisson chron_hrs4 ///   
					c.age_years##c.age_years c.age_years##ib3.edu##c.age_w1 ///
					[pweight = samp_weight] ///
					if country_4 ==1, pa vce(robust) corr(uns)	
margins, dydx(edu) at(c.age_years = (53 63)       c.age_w1 = (53))  vsquish post
est store e_2

xtpoisson chron_hrs4 ///   
					c.age_years##c.age_years c.age_years##ib3.edu##c.age_w1 ///
					[pweight = samp_weight] ///
					if country_4 ==1, pa vce(robust) corr(uns)	
margins, dydx(edu) at(c.age_years = (56 66)       c.age_w1 = (56))  vsquish post
est store e_3

xtpoisson chron_hrs4 ///   
					c.age_years##c.age_years c.age_years##ib3.edu##c.age_w1 ///
					[pweight = samp_weight] ///
					if country_4 ==1, pa vce(robust) corr(uns)	
margins, dydx(edu) at(c.age_years = (59 69)       c.age_w1 = (59))  vsquish post
est store e_4

xtpoisson chron_hrs4 ///   
					c.age_years##c.age_years c.age_years##ib3.edu##c.age_w1 ///
					[pweight = samp_weight] ///
					if country_4 ==1, pa vce(robust) corr(uns)	
margins, dydx(edu) at(c.age_years = (62 72)       c.age_w1 = (62))  vsquish post
est store e_5

xtpoisson chron_hrs4 ///   
					c.age_years##c.age_years c.age_years##ib3.edu##c.age_w1 ///
					[pweight = samp_weight] ///
					if country_4 ==1, pa vce(robust) corr(uns)	
margins, dydx(edu) at(c.age_years = (65 75)       c.age_w1 = (65))  vsquish post
est store e_6


esttab e_1 e_2 e_3 e_4 e_5 e_6 using "${workingDir}/02_tables/table3_sw.rtf", replace label star ci
		

** Netherlands

eststo clear
xtpoisson chron_hrs4 ///   
					c.age_years##c.age_years c.age_years##ib3.edu##c.age_w1 ///
					[pweight = samp_weight] ///
					if country_4 ==2, pa vce(robust) corr(uns)	
margins, dydx(edu) at(c.age_years = (50 60)       c.age_w1 = (50) )  vsquish post
est store e_1

xtpoisson chron_hrs4 ///   
					c.age_years##c.age_years c.age_years##ib3.edu##c.age_w1 ///
					[pweight = samp_weight] ///
					if country_4 ==2, pa vce(robust) corr(uns)	
margins, dydx(edu) at(c.age_years = (53 63)       c.age_w1 = (53))  vsquish post
est store e_2

xtpoisson chron_hrs4 ///   
					c.age_years##c.age_years c.age_years##ib3.edu##c.age_w1 ///
					[pweight = samp_weight] ///
					if country_4 ==2, pa vce(robust) corr(uns)	
margins, dydx(edu) at(c.age_years = (56 66)       c.age_w1 = (56))  vsquish post
est store e_3

xtpoisson chron_hrs4 ///   
					c.age_years##c.age_years c.age_years##ib3.edu##c.age_w1 ///
					[pweight = samp_weight] ///
					if country_4 ==2, pa vce(robust) corr(uns)	
margins, dydx(edu) at(c.age_years = (59 69)       c.age_w1 = (59))  vsquish post
est store e_4

xtpoisson chron_hrs4 ///   
					c.age_years##c.age_years c.age_years##ib3.edu##c.age_w1 ///
					[pweight = samp_weight] ///
					if country_4 ==2, pa vce(robust) corr(uns)	
margins, dydx(edu) at(c.age_years = (62 72)       c.age_w1 = (62))  vsquish post
est store e_5

xtpoisson chron_hrs4 ///   
					c.age_years##c.age_years c.age_years##ib3.edu##c.age_w1 ///
					[pweight = samp_weight] ///
					if country_4 ==2, pa vce(robust) corr(uns)	
margins, dydx(edu) at(c.age_years = (65 75)       c.age_w1 = (65))  vsquish post
est store e_6	

esttab e_1 e_2 e_3 e_4 e_5 e_6 using "${workingDir}/02_tables/table3_nl.rtf", replace label star ci


** UK

eststo clear
xtpoisson chron_hrs4 ///   
					c.age_years##c.age_years c.age_years##ib3.edu##c.age_w1 ///
					[pweight = samp_weight] ///
					if country_4 ==3, pa vce(robust) corr(uns)	
margins, dydx(edu) at(c.age_years = (50 60)       c.age_w1 = (50) )  vsquish post
est store e_1

xtpoisson chron_hrs4 ///   
					c.age_years##c.age_years c.age_years##ib3.edu##c.age_w1 ///
					[pweight = samp_weight] ///
					if country_4 ==3, pa vce(robust) corr(uns)	
margins, dydx(edu) at(c.age_years = (53 63)       c.age_w1 = (53))  vsquish post
est store e_2

xtpoisson chron_hrs4 ///   
					c.age_years##c.age_years c.age_years##ib3.edu##c.age_w1 ///
					[pweight = samp_weight] ///
					if country_4 ==3, pa vce(robust) corr(uns)	
margins, dydx(edu) at(c.age_years = (56 66)       c.age_w1 = (56))  vsquish post
est store e_3

xtpoisson chron_hrs4 ///   
					c.age_years##c.age_years c.age_years##ib3.edu##c.age_w1 ///
					[pweight = samp_weight] ///
					if country_4 ==3, pa vce(robust) corr(uns)	
margins, dydx(edu) at(c.age_years = (59 69)       c.age_w1 = (59))  vsquish post
est store e_4

xtpoisson chron_hrs4 ///   
					c.age_years##c.age_years c.age_years##ib3.edu##c.age_w1 ///
					[pweight = samp_weight] ///
					if country_4 ==3, pa vce(robust) corr(uns)	
margins, dydx(edu) at(c.age_years = (62 72)       c.age_w1 = (62))  vsquish post
est store e_5

xtpoisson chron_hrs4 ///   
					c.age_years##c.age_years c.age_years##ib3.edu##c.age_w1 ///
					[pweight = samp_weight] ///
					if country_4 ==3, pa vce(robust) corr(uns)	
margins, dydx(edu) at(c.age_years = (65 75)       c.age_w1 = (65))  vsquish post
est store e_6	

esttab e_1 e_2 e_3 e_4 e_5 e_6 using "${workingDir}/02_tables/table3_uk.rtf", replace label star ci
	
	

** US

eststo clear
xtpoisson chron_hrs4 ///   
					c.age_years##c.age_years c.age_years##ib3.edu##c.age_w1 ///
					[pweight = samp_weight] ///
					if country_4 ==4, pa vce(robust) corr(uns)	
margins, dydx(edu) at(c.age_years = (50 60)       c.age_w1 = (50) )  vsquish post
est store e_1

xtpoisson chron_hrs4 ///   
					c.age_years##c.age_years c.age_years##ib3.edu##c.age_w1 ///
					[pweight = samp_weight] ///
					if country_4 ==4, pa vce(robust) corr(uns)	
margins, dydx(edu) at(c.age_years = (53 63)       c.age_w1 = (53))  vsquish post
est store e_2

xtpoisson chron_hrs4 ///   
					c.age_years##c.age_years c.age_years##ib3.edu##c.age_w1 ///
					[pweight = samp_weight] ///
					if country_4 ==4, pa vce(robust) corr(uns)	
margins, dydx(edu) at(c.age_years = (56 66)       c.age_w1 = (56))  vsquish post
est store e_3

xtpoisson chron_hrs4 ///   
					c.age_years##c.age_years c.age_years##ib3.edu##c.age_w1 ///
					[pweight = samp_weight] ///
					if country_4 ==4, pa vce(robust) corr(uns)	
margins, dydx(edu) at(c.age_years = (59 69)       c.age_w1 = (59))  vsquish post
est store e_4

xtpoisson chron_hrs4 ///   
					c.age_years##c.age_years c.age_years##ib3.edu##c.age_w1 ///
					[pweight = samp_weight] ///
					if country_4 ==4, pa vce(robust) corr(uns)	
margins, dydx(edu) at(c.age_years = (62 72)       c.age_w1 = (62))  vsquish post
est store e_5

xtpoisson chron_hrs4 ///   
					c.age_years##c.age_years c.age_years##ib3.edu##c.age_w1 ///
					[pweight = samp_weight] ///
					if country_4 ==4, pa vce(robust) corr(uns)	
margins, dydx(edu) at(c.age_years = (65 75)       c.age_w1 = (65))  vsquish post
est store e_6	

esttab e_1 e_2 e_3 e_4 e_5 e_6 using "${workingDir}/02_tables/table3_us.rtf", replace label star ci


*** TABLE 4 *********************************

* Functional limitations

** Swewden
eststo clear
xtpoisson mobility ///   
					c.age_years##c.age_years c.age_years##ib3.edu##c.age_w1 ///
					[pweight = samp_weight] ///
					if country_4 ==1, pa vce(robust) corr(uns)	
margins, dydx(edu) at(c.age_years = (50 60)       c.age_w1 = (50) )  vsquish post
est store e_1

xtpoisson mobility ///   
					c.age_years##c.age_years c.age_years##ib3.edu##c.age_w1 ///
					[pweight = samp_weight] ///
					if country_4 ==1, pa vce(robust) corr(uns)	
margins, dydx(edu) at(c.age_years = (53 63)       c.age_w1 = (53))  vsquish post
est store e_2

xtpoisson mobility ///   
					c.age_years##c.age_years c.age_years##ib3.edu##c.age_w1 ///
					[pweight = samp_weight] ///
					if country_4 ==1, pa vce(robust) corr(uns)	
margins, dydx(edu) at(c.age_years = (56 66)       c.age_w1 = (56))  vsquish post
est store e_3

xtpoisson mobility ///   
					c.age_years##c.age_years c.age_years##ib3.edu##c.age_w1 ///
					[pweight = samp_weight] ///
					if country_4 ==1, pa vce(robust) corr(uns)	
margins, dydx(edu) at(c.age_years = (59 69)       c.age_w1 = (59))  vsquish post
est store e_4

xtpoisson mobility ///   
					c.age_years##c.age_years c.age_years##ib3.edu##c.age_w1 ///
					[pweight = samp_weight] ///
					if country_4 ==1, pa vce(robust) corr(uns)	
margins, dydx(edu) at(c.age_years = (62 72)       c.age_w1 = (62))  vsquish post
est store e_5

xtpoisson mobility ///   
					c.age_years##c.age_years c.age_years##ib3.edu##c.age_w1 ///
					[pweight = samp_weight] ///
					if country_4 ==1, pa vce(robust) corr(uns)	
margins, dydx(edu) at(c.age_years = (65 75)       c.age_w1 = (65))  vsquish post
est store e_6


esttab e_1 e_2 e_3 e_4 e_5 e_6 using "${workingDir}/02_tables/table4_sw.rtf", replace label star ci
		

** Netherlands

eststo clear
xtpoisson mobility ///   
					c.age_years##c.age_years c.age_years##ib3.edu##c.age_w1 ///
					[pweight = samp_weight] ///
					if country_4 ==2, pa vce(robust) corr(uns)	
margins, dydx(edu) at(c.age_years = (50 60)       c.age_w1 = (50) )  vsquish post
est store e_1

xtpoisson mobility ///   
					c.age_years##c.age_years c.age_years##ib3.edu##c.age_w1 ///
					[pweight = samp_weight] ///
					if country_4 ==2, pa vce(robust) corr(uns)	
margins, dydx(edu) at(c.age_years = (53 63)       c.age_w1 = (53))  vsquish post
est store e_2

xtpoisson mobility ///   
					c.age_years##c.age_years c.age_years##ib3.edu##c.age_w1 ///
					[pweight = samp_weight] ///
					if country_4 ==2, pa vce(robust) corr(uns)	
margins, dydx(edu) at(c.age_years = (56 66)       c.age_w1 = (56))  vsquish post
est store e_3

xtpoisson mobility ///   
					c.age_years##c.age_years c.age_years##ib3.edu##c.age_w1 ///
					[pweight = samp_weight] ///
					if country_4 ==2, pa vce(robust) corr(uns)	
margins, dydx(edu) at(c.age_years = (59 69)       c.age_w1 = (59))  vsquish post
est store e_4

xtpoisson mobility ///   
					c.age_years##c.age_years c.age_years##ib3.edu##c.age_w1 ///
					[pweight = samp_weight] ///
					if country_4 ==2, pa vce(robust) corr(uns)	
margins, dydx(edu) at(c.age_years = (62 72)       c.age_w1 = (62))  vsquish post
est store e_5

xtpoisson mobility ///   
					c.age_years##c.age_years c.age_years##ib3.edu##c.age_w1 ///
					[pweight = samp_weight] ///
					if country_4 ==2, pa vce(robust) corr(uns)	
margins, dydx(edu) at(c.age_years = (65 75)       c.age_w1 = (65))  vsquish post
est store e_6	

esttab e_1 e_2 e_3 e_4 e_5 e_6 using "${workingDir}/02_tables/table4_nl.rtf", replace label star ci


** UK

eststo clear
xtpoisson mobility ///   
					c.age_years##c.age_years c.age_years##ib3.edu##c.age_w1 ///
					[pweight = samp_weight] ///
					if country_4 ==3, pa vce(robust) corr(uns)	
margins, dydx(edu) at(c.age_years = (50 60)       c.age_w1 = (50) )  vsquish post
est store e_1

xtpoisson mobility ///   
					c.age_years##c.age_years c.age_years##ib3.edu##c.age_w1 ///
					[pweight = samp_weight] ///
					if country_4 ==3, pa vce(robust) corr(uns)	
margins, dydx(edu) at(c.age_years = (53 63)       c.age_w1 = (53))  vsquish post
est store e_2

xtpoisson mobility ///   
					c.age_years##c.age_years c.age_years##ib3.edu##c.age_w1 ///
					[pweight = samp_weight] ///
					if country_4 ==3, pa vce(robust) corr(uns)	
margins, dydx(edu) at(c.age_years = (56 66)       c.age_w1 = (56))  vsquish post
est store e_3

xtpoisson mobility ///   
					c.age_years##c.age_years c.age_years##ib3.edu##c.age_w1 ///
					[pweight = samp_weight] ///
					if country_4 ==3, pa vce(robust) corr(uns)	
margins, dydx(edu) at(c.age_years = (59 69)       c.age_w1 = (59))  vsquish post
est store e_4

xtpoisson mobility ///   
					c.age_years##c.age_years c.age_years##ib3.edu##c.age_w1 ///
					[pweight = samp_weight] ///
					if country_4 ==3, pa vce(robust) corr(uns)	
margins, dydx(edu) at(c.age_years = (62 72)       c.age_w1 = (62))  vsquish post
est store e_5

xtpoisson mobility ///   
					c.age_years##c.age_years c.age_years##ib3.edu##c.age_w1 ///
					[pweight = samp_weight] ///
					if country_4 ==3, pa vce(robust) corr(uns)	
margins, dydx(edu) at(c.age_years = (65 75)       c.age_w1 = (65))  vsquish post
est store e_6	

esttab e_1 e_2 e_3 e_4 e_5 e_6 using "${workingDir}/02_tables/table4_uk.rtf", replace label star ci
	
	

** US

eststo clear
xtpoisson mobility ///   
					c.age_years##c.age_years c.age_years##ib3.edu##c.age_w1 ///
					[pweight = samp_weight] ///
					if country_4 ==4, pa vce(robust) corr(uns)	
margins, dydx(edu) at(c.age_years = (50 60)       c.age_w1 = (50) )  vsquish post
est store e_1

xtpoisson mobility ///   
					c.age_years##c.age_years c.age_years##ib3.edu##c.age_w1 ///
					[pweight = samp_weight] ///
					if country_4 ==4, pa vce(robust) corr(uns)	
margins, dydx(edu) at(c.age_years = (53 63)       c.age_w1 = (53))  vsquish post
est store e_2

xtpoisson mobility ///   
					c.age_years##c.age_years c.age_years##ib3.edu##c.age_w1 ///
					[pweight = samp_weight] ///
					if country_4 ==4, pa vce(robust) corr(uns)	
margins, dydx(edu) at(c.age_years = (56 66)       c.age_w1 = (56))  vsquish post
est store e_3

xtpoisson mobility ///   
					c.age_years##c.age_years c.age_years##ib3.edu##c.age_w1 ///
					[pweight = samp_weight] ///
					if country_4 ==4, pa vce(robust) corr(uns)	
margins, dydx(edu) at(c.age_years = (59 69)       c.age_w1 = (59))  vsquish post
est store e_4

xtpoisson mobility ///   
					c.age_years##c.age_years c.age_years##ib3.edu##c.age_w1 ///
					[pweight = samp_weight] ///
					if country_4 ==4, pa vce(robust) corr(uns)	
margins, dydx(edu) at(c.age_years = (62 72)       c.age_w1 = (62))  vsquish post
est store e_5

xtpoisson mobility ///   
					c.age_years##c.age_years c.age_years##ib3.edu##c.age_w1 ///
					[pweight = samp_weight] ///
					if country_4 ==4, pa vce(robust) corr(uns)	
margins, dydx(edu) at(c.age_years = (65 75)       c.age_w1 = (65))  vsquish post
est store e_6	

esttab e_1 e_2 e_3 e_4 e_5 e_6 using "${workingDir}/02_tables/table4_us.rtf", replace label star ci
		

**************************************************************************************
*** Predictions for the age-vector graphs (Figure 2 and 3) ***************************
**************************************************************************************

eststo clear
foreach var of varlist chron_hrs4 mobility {
foreach c of numlist 1 2 3 4{
eststo `var': xtpoisson `var' ///   ESTIMATING THE MODEL
					c.age2_cent##i.country_4 c.age_cent##c.coh_cent##i.edu##i.country_4 [pweight = samp_weight] ///
					,pa vce(robust) 

predict `var'_pr_`c'_1 if country_4 == `c' & edu==1 // predicted values from the model
predict `var'_pr_`c'_3 if country_4 == `c' & edu==3 // predicted values from the model

}
}

*** FIGURE 2  

*** CHRONIC CONDITIONS

** SWEDEN

foreach var of varlist chron_hrs4  {
graph twoway 	line `var'_pr_1_3 age_years if age_w1==50  &  edu==3 , 	lpattern(solid)    lcolor(black)   lwidth (medthick)  	sort ///
			||  line `var'_pr_1_3 age_years if age_w1==53  &  edu==3 , 	lpattern(solid)    lcolor(black)   lwidth (medthick)  	sort ///
			||  line `var'_pr_1_3 age_years if age_w1==56  &  edu==3 , 	lpattern(solid)    lcolor(black)   lwidth (medthick)  	sort ///
			||  line `var'_pr_1_3 age_years if age_w1==59  &  edu==3 , 	lpattern(solid)    lcolor(black)   lwidth (medthick)  	sort ///
			||  line `var'_pr_1_3 age_years if age_w1==62  &  edu==3 , 	lpattern(solid)    lcolor(black)   lwidth (medthick)  	sort ///
			||  line `var'_pr_1_3 age_years if age_w1==65  &  edu==3 , 	lpattern(solid)    lcolor(black)   lwidth (medthick)  	sort ///
			||	line `var'_pr_1_1 age_years if age_w1==50  &  edu==1 , 	lpattern(dash)     lcolor(black)   lwidth (medthick)  	sort ///
			||	line `var'_pr_1_1 age_years if age_w1==53  &  edu==1 , 	lpattern(dash)     lcolor(black)   lwidth (medthick)  	sort ///
			||  line `var'_pr_1_1 age_years if age_w1==56  &  edu==1 , 	lpattern(dash)     lcolor(black)   lwidth (medthick)	   sort ///
			||  line `var'_pr_1_1 age_years if age_w1==59  &  edu==1 , 	lpattern(dash)     lcolor(black)   lwidth (medthick)	   sort ///
			||  line `var'_pr_1_1 age_years if age_w1==62  &  edu==1 , 	lpattern(dash)     lcolor(black)   lwidth (medthick)	   sort ///
			||  line `var'_pr_1_1 age_years if age_w1==65  &  edu==1 , 	lpattern(dash)     lcolor(black)   lwidth (medthick)	   sort ///
	graphregion(color(white) fcolor(white) icolor(white))  			///	
	title("Sweden", size(small) col(black)) ///
	xlabel(50(3)75, labsize(small)) xtitle("Age", size(small)) ///
	ytitle("Number of chronic conditions", size(small)) ylabel(0(0.25)1.5, labsize(small) angle(horizontal)) 	///
	yline(0.5, lpattern(shortdash) lcolor(gs10) lwidth (med)) plotregion(color(white) fcolor(white) icolor(white)) legend(off) ///
	clegend(off)
	graph save $graphs/`var'_sw.gph, replace
}



** Netherlands

sort age_years 
foreach var of varlist chron_hrs4  {
graph twoway 	line `var'_pr_2_3 age_years if age_w1==50  &  edu==3, 	lpattern(solid)    lcolor(black)   lwidth (medthick)  	sort ///
			||  line `var'_pr_2_3 age_years if age_w1==53  &  edu==3, 	lpattern(solid)    lcolor(black)   lwidth (medthick)  	sort ///
			||  line `var'_pr_2_3 age_years if age_w1==56  &  edu==3, 	lpattern(solid)    lcolor(black)   lwidth (medthick)  	sort ///
			||  line `var'_pr_2_3 age_years if age_w1==59  &  edu==3, 	lpattern(solid)    lcolor(black)   lwidth (medthick)  	sort ///
			||  line `var'_pr_2_3 age_years if age_w1==62  &  edu==3, 	lpattern(solid)    lcolor(black)   lwidth (medthick)  	sort ///
			||  line `var'_pr_2_3 age_years if age_w1==65  &  edu==3, 	lpattern(solid)    lcolor(black)   lwidth (medthick)  	sort ///
			||	line `var'_pr_2_1 age_years if age_w1==50  &  edu==1, 	lpattern(dash)     lcolor(black)   lwidth (medthick)  	sort ///
			||	line `var'_pr_2_1 age_years if age_w1==53  &  edu==1, 	lpattern(dash)     lcolor(black)   lwidth (medthick)  	sort ///
			||  line `var'_pr_2_1 age_years if age_w1==56  &  edu==1, 	lpattern(dash)     lcolor(black)   lwidth (medthick)	sort ///
			||	line `var'_pr_2_1 age_years if age_w1==59  &  edu==1, 	lpattern(dash)     lcolor(black)   lwidth (medthick)  	sort ///
			||	line `var'_pr_2_1 age_years if age_w1==62  &  edu==1, 	lpattern(dash)     lcolor(black)   lwidth (medthick)  	sort ///
			||	line `var'_pr_2_1 age_years if age_w1==65  &  edu==1, 	lpattern(dash)     lcolor(black)   lwidth (medthick)  	sort ///
	graphregion(color(white) fcolor(white) icolor(white))  			///	
	title("Netherlands", size(small) col(black)) ///
	xlabel(50(3)75, labsize(small)) xtitle("Age", size(small)) ///
	ytitle("Number of  chronic conditions", size(small)) ylabel(0(0.25)1.5, labsize(small) angle(horizontal)) 	///
	yline(0.5, lpattern(shortdash) lcolor(gs10) lwidth (med)) plotregion(color(white) fcolor(white) icolor(white)) legend(off) ///
	clegend(off)
	graph save $graphs/`var'_nl.gph, replace
}


** UK

sort age_years 
foreach var of varlist chron_hrs4  {
graph twoway 	line `var'_pr_3_3 age_years if age_w1==50  &  edu==3 , 	lpattern(solid)    lcolor(black)   lwidth (medthick)  	sort ///
			||  line `var'_pr_3_3 age_years if age_w1==53  &  edu==3 , 	lpattern(solid)    lcolor(black)   lwidth (medthick)  	sort ///
			||  line `var'_pr_3_3 age_years if age_w1==56  &  edu==3 , 	lpattern(solid)    lcolor(black)   lwidth (medthick)  	sort ///
			||  line `var'_pr_3_3 age_years if age_w1==59  &  edu==3 , 	lpattern(solid)    lcolor(black)   lwidth (medthick)  	sort ///
			||  line `var'_pr_3_3 age_years if age_w1==62  &  edu==3 , 	lpattern(solid)    lcolor(black)   lwidth (medthick)  	sort ///
			||  line `var'_pr_3_3 age_years if age_w1==65  &  edu==3 , 	lpattern(solid)    lcolor(black)   lwidth (medthick)  	sort ///
			||	line `var'_pr_3_1 age_years if age_w1==50  &  edu==1 , 	lpattern(dash)     lcolor(black)   lwidth (medthick)  	sort ///
			||	line `var'_pr_3_1 age_years if age_w1==53  &  edu==1 , 	lpattern(dash)     lcolor(black)   lwidth (medthick)  	sort ///
			||  line `var'_pr_3_1 age_years if age_w1==56  &  edu==1 , 	lpattern(dash)     lcolor(black)   lwidth (medthick)	sort ///
			||  line `var'_pr_3_1 age_years if age_w1==59  &  edu==1 , 	lpattern(dash)     lcolor(black)   lwidth (medthick)	sort ///
			||  line `var'_pr_3_1 age_years if age_w1==62  &  edu==1 , 	lpattern(dash)     lcolor(black)   lwidth (medthick)	sort ///
			||  line `var'_pr_3_1 age_years if age_w1==65  &  edu==1 , 	lpattern(dash)     lcolor(black)   lwidth (medthick)	sort ///
	graphregion(color(white) fcolor(white) icolor(white))  			///	
	title("UK", size(small) col(black)) ///
	xlabel(50(3)75, labsize(small)) xtitle("Age", size(small)) ///
	ytitle("Number of  chronic conditions", size(small)) ylabel(0(0.25)1.5, labsize(small) angle(horizontal)) 	///
	yline(0.5, lpattern(shortdash) lcolor(gs10) lwidth (med)) plotregion(color(white) fcolor(white) icolor(white)) legend(off) ///
	clegend(off)
	graph save $graphs/`var'_uk.gph, replace
}


** US

sort age_years 
foreach var of varlist chron_hrs4  {
graph twoway 	line `var'_pr_4_3 age_years if age_w1==50  &  edu==3, 	lpattern(solid)    lcolor(black)   lwidth (medthick)  	sort ///
			||  line `var'_pr_4_3 age_years if age_w1==53  &  edu==3, 	lpattern(solid)    lcolor(black)   lwidth (medthick)  	sort ///
			||  line `var'_pr_4_3 age_years if age_w1==56  &  edu==3, 	lpattern(solid)    lcolor(black)   lwidth (medthick)  	sort ///
			||  line `var'_pr_4_3 age_years if age_w1==59  &  edu==3, 	lpattern(solid)    lcolor(black)   lwidth (medthick)  	sort ///
			||  line `var'_pr_4_3 age_years if age_w1==62  &  edu==3, 	lpattern(solid)    lcolor(black)   lwidth (medthick)  	sort ///
			||  line `var'_pr_4_3 age_years if age_w1==65  &  edu==3, 	lpattern(solid)    lcolor(black)   lwidth (medthick)  	sort ///
		    ||	line `var'_pr_4_1 age_years if age_w1==50  &  edu==1, 	lpattern(dash)     lcolor(black)   lwidth (medthick)  	sort ///
			||	line `var'_pr_4_1 age_years if age_w1==53  &  edu==1, 	lpattern(dash)     lcolor(black)   lwidth (medthick)  	sort ///
			||  line `var'_pr_4_1 age_years if age_w1==56  &  edu==1, 	lpattern(dash)     lcolor(black)   lwidth (medthick)	sort ///
			||  line `var'_pr_4_1 age_years if age_w1==59  &  edu==1, 	lpattern(dash)     lcolor(black)   lwidth (medthick)	sort ///
			||  line `var'_pr_4_1 age_years if age_w1==62  &  edu==1, 	lpattern(dash)     lcolor(black)   lwidth (medthick)	sort ///
			||  line `var'_pr_4_1 age_years if age_w1==65  &  edu==1, 	lpattern(dash)     lcolor(black)   lwidth (medthick)	sort ///
	graphregion(color(white) fcolor(white) icolor(white))  			///	
	title("US", size(small) col(black)) ///
	xlabel(50(3)75, labsize(small)) xtitle("Age", size(small)) ///
	ytitle("Number of  chronic conditions", size(small)) ylabel(0(0.25)1.5, labsize(small) angle(horizontal)) 	///
	yline(0.5, lpattern(shortdash) lcolor(gs10) lwidth (med)) plotregion(color(white) fcolor(white) icolor(white)) legend(off) ///
	clegend(off)
	graph save $graphs/`var'_us.gph, replace

}

*** FIGURE 3

*** FUNCTIONAL LIMITATIONS

** SWEDEN

foreach var of varlist mobility  {
graph twoway 	line `var'_pr_1_3 age_years if age_w1==50  &  edu==3 , 	lpattern(solid)    lcolor(black)   lwidth (medthick)  	sort ///
			||  line `var'_pr_1_3 age_years if age_w1==53  &  edu==3 , 	lpattern(solid)    lcolor(black)   lwidth (medthick)  	sort ///
			||  line `var'_pr_1_3 age_years if age_w1==56  &  edu==3 , 	lpattern(solid)    lcolor(black)   lwidth (medthick)  	sort ///
			||  line `var'_pr_1_3 age_years if age_w1==59  &  edu==3 , 	lpattern(solid)    lcolor(black)   lwidth (medthick)  	sort ///
			||  line `var'_pr_1_3 age_years if age_w1==62  &  edu==3 , 	lpattern(solid)    lcolor(black)   lwidth (medthick)  	sort ///
			||  line `var'_pr_1_3 age_years if age_w1==65  &  edu==3 , 	lpattern(solid)    lcolor(black)   lwidth (medthick)  	sort ///
			||	line `var'_pr_1_1 age_years if age_w1==50  &  edu==1 , 	lpattern(dash)     lcolor(black)   lwidth (medthick)  	sort ///
			||	line `var'_pr_1_1 age_years if age_w1==53  &  edu==1 , 	lpattern(dash)     lcolor(black)   lwidth (medthick)  	sort ///
			||  line `var'_pr_1_1 age_years if age_w1==56  &  edu==1 , 	lpattern(dash)     lcolor(black)   lwidth (medthick)	   sort ///
			||  line `var'_pr_1_1 age_years if age_w1==59  &  edu==1 , 	lpattern(dash)     lcolor(black)   lwidth (medthick)	   sort ///
			||  line `var'_pr_1_1 age_years if age_w1==62  &  edu==1 , 	lpattern(dash)     lcolor(black)   lwidth (medthick)	   sort ///
			||  line `var'_pr_1_1 age_years if age_w1==65  &  edu==1 , 	lpattern(dash)     lcolor(black)   lwidth (medthick)	   sort ///
	graphregion(color(white) fcolor(white) icolor(white))  			///	
	title("Sweden", size(small) col(black)) ///
	xlabel(50(3)75, labsize(small)) xtitle("Age", size(small)) ///
	ytitle("Number of functional limitations", size(small)) ylabel(0(0.5)3, labsize(small) angle(horizontal)) 	///
	yline(1, lpattern(shortdash) lcolor(gs10) lwidth (med)) plotregion(color(white) fcolor(white) icolor(white)) legend(off) ///
	clegend(off)
	graph save $graphs/`var'_sw.gph, replace
}


** Netherlands

sort age_years 
foreach var of varlist mobility  {
graph twoway 	line `var'_pr_2_3 age_years if age_w1==50  &  edu==3, 	lpattern(solid)    lcolor(black)   lwidth (medthick)  	sort ///
			||  line `var'_pr_2_3 age_years if age_w1==53  &  edu==3, 	lpattern(solid)    lcolor(black)   lwidth (medthick)  	sort ///
			||  line `var'_pr_2_3 age_years if age_w1==56  &  edu==3, 	lpattern(solid)    lcolor(black)   lwidth (medthick)  	sort ///
			||  line `var'_pr_2_3 age_years if age_w1==59  &  edu==3, 	lpattern(solid)    lcolor(black)   lwidth (medthick)  	sort ///
			||  line `var'_pr_2_3 age_years if age_w1==62  &  edu==3, 	lpattern(solid)    lcolor(black)   lwidth (medthick)  	sort ///
			||  line `var'_pr_2_3 age_years if age_w1==65  &  edu==3, 	lpattern(solid)    lcolor(black)   lwidth (medthick)  	sort ///
			||	line `var'_pr_2_1 age_years if age_w1==50  &  edu==1, 	lpattern(dash)     lcolor(black)   lwidth (medthick)  	sort ///
			||	line `var'_pr_2_1 age_years if age_w1==53  &  edu==1, 	lpattern(dash)     lcolor(black)   lwidth (medthick)  	sort ///
			||  line `var'_pr_2_1 age_years if age_w1==56  &  edu==1, 	lpattern(dash)     lcolor(black)   lwidth (medthick)	sort ///
			||	line `var'_pr_2_1 age_years if age_w1==59  &  edu==1, 	lpattern(dash)     lcolor(black)   lwidth (medthick)  	sort ///
			||	line `var'_pr_2_1 age_years if age_w1==62  &  edu==1, 	lpattern(dash)     lcolor(black)   lwidth (medthick)  	sort ///
			||	line `var'_pr_2_1 age_years if age_w1==65  &  edu==1, 	lpattern(dash)     lcolor(black)   lwidth (medthick)  	sort ///
	graphregion(color(white) fcolor(white) icolor(white))  			///	
	title("Netherlands", size(small) col(black)) ///
	xlabel(50(3)75, labsize(small)) xtitle("Age", size(small)) ///
	ytitle("Number of functional limitations", size(small)) ylabel(0(0.5)3, labsize(small) angle(horizontal)) 	///
	yline(1, lpattern(shortdash) lcolor(gs10) lwidth (med)) plotregion(color(white) fcolor(white) icolor(white)) legend(off) ///
	clegend(off)
	graph save $graphs/`var'_nl.gph, replace
}


** UK

sort age_years 
foreach var of varlist mobility  {
graph twoway 	line `var'_pr_3_3 age_years if age_w1==50  &  edu==3 , 	lpattern(solid)    lcolor(black)   lwidth (medthick)  	sort ///
			||  line `var'_pr_3_3 age_years if age_w1==53  &  edu==3 , 	lpattern(solid)    lcolor(black)   lwidth (medthick)  	sort ///
			||  line `var'_pr_3_3 age_years if age_w1==56  &  edu==3 , 	lpattern(solid)    lcolor(black)   lwidth (medthick)  	sort ///
			||  line `var'_pr_3_3 age_years if age_w1==59  &  edu==3 , 	lpattern(solid)    lcolor(black)   lwidth (medthick)  	sort ///
			||  line `var'_pr_3_3 age_years if age_w1==62  &  edu==3 , 	lpattern(solid)    lcolor(black)   lwidth (medthick)  	sort ///
			||  line `var'_pr_3_3 age_years if age_w1==65  &  edu==3 , 	lpattern(solid)    lcolor(black)   lwidth (medthick)  	sort ///
			||	line `var'_pr_3_1 age_years if age_w1==50  &  edu==1 , 	lpattern(dash)     lcolor(black)   lwidth (medthick)  	sort ///
			||	line `var'_pr_3_1 age_years if age_w1==53  &  edu==1 , 	lpattern(dash)     lcolor(black)   lwidth (medthick)  	sort ///
			||  line `var'_pr_3_1 age_years if age_w1==56  &  edu==1 , 	lpattern(dash)     lcolor(black)   lwidth (medthick)	sort ///
			||  line `var'_pr_3_1 age_years if age_w1==59  &  edu==1 , 	lpattern(dash)     lcolor(black)   lwidth (medthick)	sort ///
			||  line `var'_pr_3_1 age_years if age_w1==62  &  edu==1 , 	lpattern(dash)     lcolor(black)   lwidth (medthick)	sort ///
			||  line `var'_pr_3_1 age_years if age_w1==65  &  edu==1 , 	lpattern(dash)     lcolor(black)   lwidth (medthick)	sort ///
	graphregion(color(white) fcolor(white) icolor(white))  			///	
	title("UK", size(small) col(black)) ///
	xlabel(50(3)75, labsize(small)) xtitle("Age", size(small)) ///
	ytitle("Number of functional limitations", size(small)) ylabel(0(0.5)3, labsize(small) angle(horizontal)) 	///
	yline(1, lpattern(shortdash) lcolor(gs10) lwidth (med)) plotregion(color(white) fcolor(white) icolor(white)) legend(off) ///
	clegend(off)
	graph save $graphs/`var'_uk.gph, replace
}


** US

sort age_years 
foreach var of varlist mobility  {
graph twoway 	line `var'_pr_4_3 age_years if age_w1==50  &  edu==3, 	lpattern(solid)    lcolor(black)   lwidth (medthick)  	sort ///
			||  line `var'_pr_4_3 age_years if age_w1==53  &  edu==3, 	lpattern(solid)    lcolor(black)   lwidth (medthick)  	sort ///
			||  line `var'_pr_4_3 age_years if age_w1==56  &  edu==3, 	lpattern(solid)    lcolor(black)   lwidth (medthick)  	sort ///
			||  line `var'_pr_4_3 age_years if age_w1==59  &  edu==3, 	lpattern(solid)    lcolor(black)   lwidth (medthick)  	sort ///
			||  line `var'_pr_4_3 age_years if age_w1==62  &  edu==3, 	lpattern(solid)    lcolor(black)   lwidth (medthick)  	sort ///
			||  line `var'_pr_4_3 age_years if age_w1==65  &  edu==3, 	lpattern(solid)    lcolor(black)   lwidth (medthick)  	sort ///
		    ||	line `var'_pr_4_1 age_years if age_w1==50  &  edu==1, 	lpattern(dash)     lcolor(black)   lwidth (medthick)  	sort ///
			||	line `var'_pr_4_1 age_years if age_w1==53  &  edu==1, 	lpattern(dash)     lcolor(black)   lwidth (medthick)  	sort ///
			||  line `var'_pr_4_1 age_years if age_w1==56  &  edu==1, 	lpattern(dash)     lcolor(black)   lwidth (medthick)	sort ///
			||  line `var'_pr_4_1 age_years if age_w1==59  &  edu==1, 	lpattern(dash)     lcolor(black)   lwidth (medthick)	sort ///
			||  line `var'_pr_4_1 age_years if age_w1==62  &  edu==1, 	lpattern(dash)     lcolor(black)   lwidth (medthick)	sort ///
			||  line `var'_pr_4_1 age_years if age_w1==65  &  edu==1, 	lpattern(dash)     lcolor(black)   lwidth (medthick)	sort ///
	graphregion(color(white) fcolor(white) icolor(white))  			///	
	title("US", size(small) col(black)) ///
	xlabel(50(3)75, labsize(small)) xtitle("Age", size(small)) ///
	ytitle("Number of functional limitations", size(small)) ylabel(0(0.5)3, labsize(small) angle(horizontal)) 	///
	yline(1, lpattern(shortdash) lcolor(gs10) lwidth (med)) plotregion(color(white) fcolor(white) icolor(white)) legend(off) ///
	clegend(off)
	graph save $graphs/`var'_us.gph, replace

}


*** FIGURE 2

graph combine $graphs/chron_hrs4_sw.gph $graphs/chron_hrs4_nl.gph ///
              $graphs/chron_hrs4_uk.gph $graphs/chron_hrs4_us.gph, ///
              graphregion(fcolor(white)) xcommon 
graph save $graphs/figure2.gph, replace

			  
*** FIGURE 3
			  
graph combine $graphs/mobility_sw.gph $graphs/mobility_nl.gph ///
              $graphs/mobility_uk.gph $graphs/mobility_us.gph, ///
              graphregion(fcolor(white)) xcommon 	
graph save $graphs/figure3.gph, replace
			  
			 

