*************************************
******* Preparting ELSA data  *******
*************************************

// specify your directions here

global workingDir 	"C:\Users\liliy\Dropbox\01_Projects\03_SHARE_CAD_edu_health\04_dofiles\Leopold_2018"

global basis 		"C:\Users\liliy\Dropbox\01_Projects\03_SHARE_CAD_edu_health\04_dofiles\Leopold_2018\Data\ELSA"   // oirginal SHARE and HRS files


global working 		"${workingDir}/01_working_data"	   // working data - data saved after merging and recodings
global tables 		"${workingDir}/02_tables" 		   // tables 
global graphs 		"${workingDir}/03_graphs" 		   // graphs
global dofiles 		"${workingDir}/04_dofiles" 		   // do-files


*** generate a data set with additional information on education from wave 0

use $basis\UKDA-5050-stata\stata\stata13_se\wave_0_common_variables_v2.dta, clear

gen birth_year=2000 - ager

keep idauniq educend topqual2 topqual3 ager birth_year

save $working\elsa_edu_w0.dta, replace


*** prepare the harmonized elsa file ***

clear matrix
 
use $basis\H_ELSA_13.dta, clear


//Use the ELSA HRS 
clear 
tempfile aux 
use idauniq inw? r?iwstat r?iwindy ///
    ragender raracem rabyear rabplace r1cwtresp  ///
	radyear raedyrs_e raedisced raeduc_e ///
	r?walk100a r?sita r?chaira r?climsa ///
	r?clim1a r?stoopa r?armsa r?pusha ///
	r?lifta r?dimea ///
	r?dressa r?walkra ///
	r?batha r?eata r?beda r?toilta ///
	r?mapa r?mealsa r?shopa r?phonea r?medsa ///
	r?moneya  ///
	r?hibpe r?diabe r?cancre ///
	r?lunge r?stroke r?arthre  r?lgmusa r?bmi r?smokev r?smoken ///
	using $basis/H_ELSA_13.dta, clear
save `aux', replace

//rename variables for reshape

rename r#iwindy riwindy#

rename r#walk100a rwalk100a#

rename r#sita rsita#

rename r#chaira rchaira#

rename r#climsa rclimsa#

rename r#clim1a rclim1a#

rename r#stoopa rstoopa#

rename r#armsa rarmsa#

rename r#pusha rpusha#

rename r#lifta rlifta#

rename r#dimea rdimea#

rename r#hibpe rhibpe#

rename r#diabe rdiabe# 

rename r#cancre rcancre# 

rename r#lunge rlunge#

rename r#stroke rstroke#

rename r#arthre rarthre#

rename r#iwstat riwstat#

rename r#lgmusa  rlgmusa#

rename r#dressa rdressa#

rename r#walkra rwalkra#

rename r#batha rbatha#

rename r#eata reata#

rename r#beda rbeda#

rename r#toilta rtoilta#

rename r#bmi rbmi#

rename r#smokev rsmokev#

rename r#smoken rsmoken#

** add education info from wave 0

merge m:1 idauniq using "$working\elsa_edu_w0.dta", keep (1 3) nogen // this data is created in the do-file 

***********************************************

//rehshape to long format:

reshape long inw riwstat riwindy ///
			 rhibpe rdiabe rcancre ///
	         rlunge rstroke rarthre ///
	         rcenreg ///
			 rwalk100a rsita rchaira rclimsa rclim1a rstoopa rarmsa rpusha rlifta rdimea ///
			 rlgmusa rbmi rsmokev rsmoken, ///
i(idauniq) j(wave)

************************************************

* save elsa long
save $working\elsa_long, replace


****************************************************
****************************************************
*** PREPARATION OF THE HARMONIZED FILE *************
****************************************************
****************************************************

use $working\elsa_long, clear

*** id the same name as in SHARE

tostring idauniq, gen(mergeid)

***** svyear

gen svyear=.
replace svyear=2002 if wave==1
replace svyear=2004 if wave==2
replace svyear=2006 if wave==3
replace svyear=2008 if wave==4
replace svyear=2010 if wave==5
replace svyear=2012 if wave==6


***********************************************

***** Year of death

clonevar diedy = radyear

bys mergeid (svyear): gen auxsvyear_died= svyear if riwstat ==5 
bys mergeid (svyear): egen svyear_died =  max(auxsvyear_died)

replace diedy = svyear_died if diedy==.x 


***** Died or not during the panel 

gen died= 1 if diedy!=.
replace died= 0 if diedy==.


************************************************
* Only actual observations, not only potential

gen aux = wave if inw == 1

bysort mergeid (wave): egen lastwave = max(aux)
label var lastwave "First wave respondent participated in HRS (wo censoring)"

bysort mergeid (wave): egen realfirstwave = min(aux)
label var realfirstwave "First wave respondent participated in HRS (wo censoring)"

*** drop so that only if resondent actually participated in a wave he or she has a value for that wave

drop if wave!=aux

*** Age in 2002

gen age_w1 = 2002- rabyear

drop if age_w1 <50 // only the sample 50+
drop if age_w1 >65 // only the sample until 65 at the first wave (= 80 at the last wave)

*** Age in years

replace riwindy = svyear if riwindy==.

gen age_years = riwindy - rabyear // year of the interview minus year of birth

****************************
**** Edu cat ***************

clonevar edu_cat_=raeduc_e

gen edu=.
replace edu=1 if  edu_cat_<=1
replace edu=2 if  edu_cat_==3 | edu_cat_==4
replace edu=3 if  edu_cat_==5 

replace edu = 1 if edu==. & raedyrs_e ==0 | raedyrs_e ==11

replace edu = 2 if edu==. & raedyrs_e ==13 

*** too few higher educated in the edu_cat. Replace edu higher is years of edu 16 or more,
*** replace if higher edu according to isced, but for some reason not in edu_cat

replace edu = 3 if edu==. & topqual3 == 1
replace edu = 2 if edu==. & topqual3 == 2
replace edu = 2 if edu==. & topqual3 == 3
replace edu = 2 if edu==. & educend >=6 & educend <=8
replace edu = 1 if edu==. & topqual3 == 4 | topqual3 == 5 | topqual3 == 7

*** too few higher educated in the edu_cat. Replace edu higher is years of edu 16 or more,
*** replace if higher edu according to isced, but for some reason not in edu_cat

replace edu = 3 if raedisced==5 & edu !=3 

tabulate edu, gen(edu_)



**********************************

bysort mergeid (wave): gen n=_n


***********************************

drop if n==1 & svyear!=2002

*********************
*chonic conditions **
*********************

egen chron_hrs5=anycount( rhibpe rdiabe rcancre rstroke rlunge), v(1)

egen miss_ch5=rowmiss(rhibpe rdiabe rcancre rstroke rlunge )

replace chron_hrs5 =. if chron_hrs==0 & miss_ch==5


egen chron_hrs4=anycount( rhibpe rdiabe rstroke rlunge), v(1)

egen miss_ch4=rowmiss(rhibpe rdiabe rstroke rlunge )

replace chron_hrs4 =. if chron_hrs4==0 & miss_ch4==4


*************************************
* Chronic conditions  ***************
*************************************

gen high_BP = rhibpe ==1 & rhibpe!=.
 
replace high_BP =. if rhibpe ==.

gen stroke = rstroke==1

gen diabet = rdiabe==1
gen cancer = rcancre==1
gen lung_di = rlunge==1
gen artr = rarthre==1


*****************************************
* Functional limitations ****************
*****************************************

foreach var of varlist rwalk1 rsit rchair rclims rclim1 rstoop rarms rpush rlift rdime {
			  replace `var'=. if `var'>1
}

egen mobility=anycount(rwalk1 rsit rchair rclims rclim1 rstoop rarms rpush rlift rdime), v(1)
egen miss_mobility=rowmiss(rwalk1 rsit rchair rclims rclim1 rstoop rarms rpush rlift rdime)

replace mobility=. if mobility==0 & miss_mobility==10

gen mob_2=mobility>=2
replace mob_2=. if mobility==.

gen mob_3=mobility>=3
replace mob_3=. if mobility==.


gen walk   = rwalk1 ==1
gen sit    = rsit   ==1
gen chair  = rchair ==1
gen stair  = rclims ==1
gen stair1 = rclim1 ==1
gen stoop  = rstoop ==1
gen arms   = rarms  ==1
gen push   = rpush  ==1
gen lift   = rlift  ==1
gen dime   = rdime  ==1


* large muscles

clonevar lgmuscle = rlgmusa


*********************
*** Controls ********
*********************

***** gender

rename ragender gender

gen male=gender==1
label variable male "Male"

***** year of birth

rename rabyear yrbirth
drop if yrbirth==.m

* age

gen age = svyear - yrbirth

gen age_c= age-50

gen age_2 = age * age

sum age_2

gen age_2_c = age_2 - r(mean)

gen aux_age_w1 = 2004-yrbirth
gen age_w1_c = aux_age_w1-50	

************ FROM HERE 

*race

clonevar race=raracem

gen white=(race==1)
gen black=(white!=1)

*place of birth 

clonevar immig=rabplace

***** Drop immigrants

drop if immig==11

***********************
*** DROPOUTS **********
***********************

gen dropout = lastwave<6

gen uk=1

************************
*** sampling weight   **
************************

clonevar samp_weight = r1cwtresp

** HB

gen bmi = rbmi
gen smokev = rsmokev
gen smoken = rsmoken

save $working\elsa_cr.dta, replace

		
