***********************************************************
*****  MERGING AND PREPARING THE ORIGINAL DATA SWEDEN *****
***********************************************************

*** To procedd with this do-file, the do-file 160510_share_dead_chron has to be run

// specify your working directions here
			
global workingDir 	"C:\Users\liliy\Dropbox\01_Projects\03_SHARE_CAD_edu_health\04_dofiles\Leopold_2018"

global basis 		"C:\Users\liliy\Dropbox\01_Projects\03_SHARE_CAD_edu_health\04_dofiles\Leopold_2018\Data\SHARE_HRS"   // oirginal SHARE files

global basisw1		"${basis}/W1" // oirginal SHARE W1 data, downloaded on 27.10.2014
global basisw2		"${basis}/W2" // oirginal SHARE W2 data, downloaded on 27.10.2014
global basisw3		"${basis}/W3" // oirginal SHARE W3 data, downloaded on 27.10.2014
global basisw4		"${basis}/W4" // oirginal SHARE W4 data, downloaded on 27.10.2014
global basisw5		"${basis}/W5" // oirginal SHARE W4 data, downloaded on 27.10.2014


global working 		"${workingDir}/01_working_data"	   // working data - data saved after merging and recodings
global tables 		"${workingDir}/02_tables" 		   // tables 
global graphs 		"${workingDir}/03_graphs" 		   // graphs
global graphspap 	"${workingDir}/03_graphs/Paper"    // graphs
global dofiles 		"${workingDir}/04_dofiles" 		   // do-files	



*********************************************************************************************************
**** GENERATING IN SHARE HEALTH VARIABLES IDENTICAL WITH HRS AND GENERATING AN INDICATOR FOR DEATHS   ***
*********************************************************************************************************

global basis_ph 	"${basis}/share_ph/"  // share physical health data

global basisw1		"${basis}/W1" // oirginal SHARE W1 data, downloaded on 27.10.2014
global basisw2		"${basis}/W2" // oirginal SHARE W2 data, downloaded on 27.10.2014
global basisw3		"${basis}/W3" // oirginal SHARE W3 data, downloaded on 27.10.2014
global basisw4		"${basis}/W4" // oirginal SHARE W4 data, downloaded on 27.10.2014
global basisw5		"${basis}/W5" // oirginal SHARE W4 data, downloaded on 27.10.2014


set more off

**** CHRONIC CONDITIONS AQUIVALENT TO HRS   ****
*W1
use  "${basis_ph}sharew1_ph.dta", clear

drop if mergeid=="no int w.`X'"

gen wave1 =1

keep mergeid ph006d2 ph006d5 ph006d10 ph006d6 ph006d4 ph006d8 wave1 

/*
*ph006d2 - high blood pressure
*ph006d5 - diabetes
*ph006d10 - cancer
*ph006d6 - lung disease
*ph006d4 - stroke
*ph006d8 - arthritis
*/

foreach VAR in varlist ph006d2 ph006d5 ph006d10 ph006d6 ph006d4 ph006d8  {
cap rename `VAR' `VAR'1
}

save "${working}ph_w1.dta",replace


*W2
use  "${basis_ph}sharew2_ph.dta", clear

drop if mergeid=="no int w.`X'"

gen wave2 =2

keep mergeid ph006d2 ph006d5 ph006d10 ph006d6 ph006d4 ph006d8 wave2 

foreach VAR in varlist ph006d2 ph006d5 ph006d10 ph006d6 ph006d4 ph006d8{
cap rename `VAR' `VAR'2
}

save "${working}ph_w2.dta",replace

*W4
use  "${basis_ph}sharew4_ph.dta", clear

drop if mergeid=="no int w.`X'"

gen wave4 =4

keep mergeid ph006d2 ph006d5 ph006d10 ph006d6 ph006d4 ph006d8 wave4

foreach VAR in varlist ph006d2 ph006d5 ph006d10 ph006d6 ph006d4 ph006d8 {
cap rename `VAR' `VAR'4
}

save "${working}ph_w4.dta",replace

*W5

use  "${basis_ph}sharew5_ph.dta", clear

drop if mergeid=="no int w.`X'"

gen wave5 = 5

keep mergeid ph006d2 ph006d5 ph006d10 ph006d6 ph006d4 ph006d19 ph006d20 wave5 ///
                     
*ph006d19- rheumatoid arthritis
*ph006d20- osteoarthritis/other rheumatism
rename ph006d20 ph006d8

foreach VAR in varlist ph006d2 ph006d5 ph006d10 ph006d6 ph006d4 ph006d8 {
cap rename `VAR' `VAR'5
}

save "${working}ph_w5.dta",replace

*** Merging in a wide format

use "${working}ph_w1.dta", clear

merge 1:1 mergeid using "${working}ph_w2.dta", keep (1 3) nogen
merge 1:1 mergeid using "${working}ph_w4.dta", keep (1 3) nogen
merge 1:1 mergeid using "${working}ph_w5.dta", keep (1 3) nogen

save "${working}chronic.dta",replace

*** Reshaping into a long format

reshape long wave ph006d2 ph006d5 ph006d10 ph006d6 ph006d4 ph006d8, i(mergeid)

* Number of chronic conditions 

foreach var of varlist ph006d2 ph006d5 ph006d10 ph006d6 ph006d4 ph006d8 {
			  replace `var'=. if `var'<0
}

*Chronic conditions


egen chron_hrs5=anycount(ph006d2 ph006d5 ph006d10 ph006d6 ph006d4), v(1)

egen miss_ch5=rowmiss(ph006d2 ph006d5 ph006d10 ph006d6 ph006d4)

replace chron_hrs5 =. if chron_hrs5==0 & miss_ch5==5

egen chron_hrs4=anycount(ph006d2 ph006d5 ph006d6 ph006d4), v(1)

egen miss_ch4=rowmiss(ph006d2 ph006d5 ph006d6 ph006d4)

replace chron_hrs4 =. if chron_hrs4==0 & miss_ch4==4


drop if wave==. // dropping empty cells for those who did not participate in a particular wave

gen high_BP = ph006d2==1 
gen stroke = ph006d4==1
gen diabet = ph006d5==1
gen cancer = ph006d10==1
gen lung_di = ph006d6==1
gen artr = ph006d8==1


keep chron_hrs5 chron_hrs4 high_BP stroke diabet cancer lung_di artr mergeid wave

save "${working}chron_long.dta",replace

****************************************************
**** functional limitations AQUIVALENT TO HRS   ****
****************************************************


*W1
use  "${basis_ph}sharew1_ph.dta", clear

drop if mergeid=="no int w.`X'"

gen wave1 =1

keep mergeid wave1 ph009_2 ///
     ph048d1 ph048d2 ph048d3 ph048d4 ph048d5 ph048d6 ph048d7 ph048d8 ph048d9 ph048d10


foreach VAR in varlist ph009_2 ///
                       ph048d1 ph048d2 ph048d3 ph048d4 ph048d5 ph048d6 ph048d7 ///
					   ph048d8 ph048d9 ph048d10 {
cap rename `VAR' `VAR'1
}

save "${working}ph_w1.dta",replace


*W2
use  "${basis_ph}sharew2_ph.dta", clear

drop if mergeid=="no int w.`X'"

gen wave2 =2

keep mergeid wave2 ph009_2 ///
                       ph048d1 ph048d2 ph048d3 ph048d4 ph048d5 ph048d6 ph048d7 ///
					   ph048d8 ph048d9 ph048d10

foreach VAR in varlist  ph009_2 ///
                       ph048d1 ph048d2 ph048d3 ph048d4 ph048d5 ph048d6 ph048d7 ///
					   ph048d8 ph048d9 ph048d10{
cap rename `VAR' `VAR'2
}

save "${working}ph_w2.dta",replace

*W4
use  "${basis_ph}sharew4_ph.dta", clear

drop if mergeid=="no int w.`X'"

gen wave4 =4

keep mergeid  wave4 ph009_2 ///
                       ph048d1 ph048d2 ph048d3 ph048d4 ph048d5 ph048d6 ph048d7 ///
					   ph048d8 ph048d9 ph048d10

foreach VAR in varlist  ph009_2 ///
                       ph048d1 ph048d2 ph048d3 ph048d4 ph048d5 ph048d6 ph048d7 ///
					   ph048d8 ph048d9 ph048d10 {
cap rename `VAR' `VAR'4
}

save "${working}ph_w4.dta",replace

*W5

use  "${basis_ph}sharew5_ph.dta", clear

drop if mergeid=="no int w.`X'"

gen wave5 = 5

keep mergeid  ph009_2 wave5 ///
                       ph048d1 ph048d2 ph048d3 ph048d4 ph048d5 ph048d6 ph048d7 ///
					   ph048d8 ph048d9 ph048d10 ph006d20

foreach VAR in varlist  ph009_2 ///
                       ph048d1 ph048d2 ph048d3 ph048d4 ph048d5 ph048d6 ph048d7 ///
					   ph048d8 ph048d9 ph048d10{
cap rename `VAR' `VAR'5
}

save "${working}ph_w5.dta",replace

*** Merging in a wide format

use "${working}ph_w1.dta", clear

merge 1:1 mergeid using "${working}ph_w2.dta", keep (1 3) nogen
merge 1:1 mergeid using "${working}ph_w4.dta", keep (1 3) nogen
merge 1:1 mergeid using "${working}ph_w5.dta", keep (1 3) nogen

save "${working}func_limit.dta",replace


*** Reshaping into a long format

reshape long wave  ph009_2 ///
                       ph048d1 ph048d2 ph048d3 ph048d4 ph048d5 ph048d6 ph048d7 ///
					   ph048d8 ph048d9 ph048d10, i(mergeid)

* Number mob limit

foreach var of varlist ph009_2 ///
                       ph048d1 ph048d2 ph048d3 ph048d4 ph048d5 ph048d6 ph048d7 ///
					   ph048d8 ph048d9 ph048d10{
			  replace `var'=. if `var'<0
}


*Mobility
egen mobility=anycount(ph048d1 ph048d2 ph048d3 ph048d4 ph048d5 ph048d6 ph048d7 ///
					   ph048d8 ph048d9 ph048d10), v(1)
					   
egen miss_mobility=rowmiss(ph048d1 ph048d2 ph048d3 ph048d4 ph048d5 ph048d6 ph048d7 ///
					   ph048d8 ph048d9 ph048d10)

replace mobility=. if mobility==0 & miss_mobility==10

gen mob_2=mobility>=2
replace mob_2=. if mobility==.

gen mob_3=mobility>=3
replace mob_3=. if mobility==.

* each item

gen  walk   = ph048d1==1
gen  sit    = ph048d2==1
gen  chair  = ph048d3==1
gen  stair  = ph048d4==1
gen  stair1 = ph048d5==1
gen  stoop  = ph048d6==1
gen  arms   = ph048d7==1
gen  push   = ph048d8==1
gen  lift   = ph048d9==1
gen  dime   = ph048d10==1



drop if wave==. // dropping empty cells for those who did not participate in a particular wave

save "${working}func_limit_long.dta",replace

**********************************************************
**** DIED ************************************************

use $basisw5\sharew5_rel5-0-0_cv_r, clear

drop if mergeid=="no int w.5"

merge 1:1 mergeid using $basisw5\sharew5_rel5-0-0_xt.dta, keep (1 3) nogen

gen wave =5
gen died =  deceased==1
gen diedy = xt009_

keep mergeid wave /// individual id identical across datasets an waves
	 diedy died   /// dead
	 
sort mergeid
save "${working}died_w5.dta", replace
		

***********************************************************************
********       EASYSHARE      *****************************************
***********************************************************************
  
use $basis\easySHARE_rel5-0-0_v12.dta, clear // easy share in STATA 12 format

merge m:1 mergeid using "${basis}/W1/sharew1_rel5-0-0_gv_weights.dta", keep (1 3) nogen // merge the data set with cross-sectional weights
merge m:1 mergeid using "${working}died_w5.dta", keep (1 3) nogen // this data is created in the do-file 
merge m:1 mergeid wave using "${working}chron_long.dta", keep (1 3) nogen // this data is created in the do-file 
merge m:1 mergeid wave using "${working}func_limit_long.dta", keep (1 3) nogen // this data is created in the do-file 

*** Sample selction

bysort mergeid (wave): egen minw= min(wave) 

drop if minw!=1 // only those who participated in the first wave

keep if country == 13 | country == 14

keep if birth_country==752 | birth_country==528 // keep only native Swedes and Dutch

gen age_w1 = 2004-dn003_mod

drop if age_w1 <50 // only the sample 50+
drop if age_w1 >65 // only the sample until 60 at the first wave (= 80 at the last wave)

*** Exploration patterns

fre wavepart // run "ssc instal fre" if you do not have the fre command

egen newid = group(mergeid)
xtset newid wave

xtdescribe

*** Died 

replace died=0 if died==. // if no information on whether dead or alive we consider the person alive

******************************************************
***** Preparation ************************************
******************************************************

bysort mergeid: egen last=max(wave)

egen pick = tag(mergeid )

fre last if pick

*****************************
**** Variables **************

gen svyear = .
replace svyear = 2004 if wave == 1
replace svyear = 2007 if wave == 2
replace svyear = 2009 if wave == 3
replace svyear = 2011 if wave == 4
replace svyear = 2013 if wave == 5

* age

gen age_years = int_year - dn003_mod

lab var age_years "Age"


* decoding missing values

mvdecode lgmuscle co007_ isced1997_r eduyears_mod, mv(-15 -13 -12 -3)

* Education
gen edu =.
replace edu= 1 if isced1997_r<=2
replace edu= 2 if isced1997_r==3 | isced1997_r==4
replace edu= 3 if isced1997_r==5

replace edu= 1 if edu==. & eduyears_mod <=11
replace edu= 2 if edu==. & (eduyears_mod ==12 | eduyears_mod ==13)
replace edu= 3 if edu==. & (eduyears_mod >=14 | eduyears_mod <=19)

tabulate edu, gen (edu_)

label variable edu_1 "Lower"
label variable edu_2 "Intermed."
label variable edu_3 "Higher"


*** Gender

gen male=female==0
label variable male "Male"


*** Dropouts

** as dropouts are defined those who were not observed in the final wave

bysort mergeid (wave): egen max_wave= max(wave)
bysort mergeid (wave): gen dropout= max_wave<5


bysort mergeid (wave): gen n=_n

*********************************
** Sampling weights            **
*********************************

clonevar samp_weight = cciw_w1 


****** Health behav
gen bmi = bmi_mod
replace bmi = . if bmi_mod <=-1

gen smokev = ever_smoked
replace smokev =. if ever_smoked <=-1
replace smokev =1 if ever_smoked ==1
replace smokev =0 if ever_smoked ==5

gen smoken = smoking
replace smoken =. if smoking <=-1
replace smoken =1 if smoking ==1
replace smoken =0 if smoking ==5

**********************************************************************
*********** APPENDING US DATA  ***************************************
**********************************************************************

append using $working\hrs_cr.dta // data created in preparation_US

append using $working\elsa_cr.dta // data created in preparation_US

* Country recode (for description)

replace country=100 if us==1 

replace country=200 if uk==1 

recode country (100=4 "US") (200=3 "UK") ///
			   (13=1 "Sweden")(14=2 "Netherlands"), gen (country_4)

********* age years

replace yrbirth = dn003_mod if yrbirth == . 


recode age_w1 (50/54 = 1)(55/59 = 2)(60/65 = 3), gen (cohort)
label de cohort1 1 "50-54" 2 "55-59"  3 "60-65 in Wave 1" 
labe val cohort cohort1


** generate centered variables for tables

sum age_years
gen age_cent= age_years - r(mean)

gen age2_ = age_years* age_years
sum age2_

gen age2_cent = age2_ - r(mean)

gen coh_cent= age_w1 - 50

gen age_w12 = age_w1*age_w1
sum age_w12 
gen coh2_cent = age_w12 - r(mean)


recode age_w1 (50/52 = 1) (53/55 = 2) (56/58 = 3) ///
              (59/61 = 4) (62/65 = 5), gen (coh_5)

bysort mergeid (svyear): gen auxid = _n
gen aux1 = auxid == 1
gen num = sum(aux1)


label var age_years "Age"
label var yrbirth "Year of birth"
label var age_w1 "Cohort"

label var chron_hrs5 "Nr. of chronic conditions"
label var high_BP "High blood pressure"
label var diabet "Diabetes"

label var died "Died"
label var dropout "Dropout"


* FOR attrition analysis


foreach var of varlist chron_hrs4 mobility  n {
gen `var'w1died=`var' if wave==1 & died==1
gen `var'w1drop=`var' if wave==1 & dropout==1 & died==0
gen `var'w1ndd=`var'  if wave==1 & dropout==0 & died==0

}


drop pick

egen pick = tag(mergeid )


gen drop_stat= .
replace drop_stat = 1 if dropout==0 & died==0
replace drop_stat = 2 if dropout==1 & died==0
replace drop_stat = 3 if died==1

** variables for table 1

gen obesity = bmi > 30 if wave == 1 
gen obesity_uk = bmi > 30 if wave == 2 & country_4 == 3

replace obesity = obesity_uk if obesity ==.  // bmi is not included in the first wave in the uk


save $working\180918_an.dta, replace


